Module analyzed

Module analyzed 

Structs

AnalyzedExpr
An expression that has been analyzed and ready to be drawn.

Enums

Variable
Special variable names that are used in expressions to be graphed.

Functions

predict_independent
Predicts and extracts the independent variable from the given expression.