pub struct AnalyzedExpr {
pub expr: Expr,
pub independent: Variable,
pub color: (f64, f64, f64),
}Expand description
An expression that has been analyzed and ready to be drawn.
Fields
expr: ExprThe expression to draw.
independent: VariableThe independent variable.
color: (f64, f64, f64)The color of the expression, given as an RGB tuple with each value in the range 0.0 to 1.0.
The default color is a solid red.
Implementations
Sourceimpl AnalyzedExpr
impl AnalyzedExpr
Sourcepub fn new(expr: Expr) -> Self
pub fn new(expr: Expr) -> Self
Analyze the given expression and return a new AnalyzedExpr.
Sourcepub fn parse(expr: &str) -> Result<Self, Vec<Error>>
pub fn parse(expr: &str) -> Result<Self, Vec<Error>>
Parses and analyzes the given expression and returns a new AnalyzedExpr.
Sourcepub fn with_color(self, color: (f64, f64, f64)) -> Self
pub fn with_color(self, color: (f64, f64, f64)) -> Self
Sets the color of the expression.
Returns the expression itself to allow chaining.