pub struct Point<T> {
pub coordinates: GraphPoint<T>,
pub color: (f64, f64, f64),
pub label: Option<String>,
}Expand description
A point to draw in a graph with style information.
The default point color is red.
Fields
coordinates: GraphPoint<T>The coordinates of the point to draw.
color: (f64, f64, f64)The color of the point, given as an RGB tuple with each value in the range 0.0 to 1.0.
The default color is a solid red.
label: Option<String>The label of the point. If omitted, the point will be labeled with its coordinates, to a maximum of 3 decimal places for each coordinate.
Implementations
Sourceimpl<T> Point<T>
impl<T> Point<T>
Sourcepub fn new(coordinates: impl Into<GraphPoint<T>>) -> Point<T>
pub fn new(coordinates: impl Into<GraphPoint<T>>) -> Point<T>
Creates a new point with the given coordinates.
Sourcepub fn with_color(self, color: (f64, f64, f64)) -> Point<T>
pub fn with_color(self, color: (f64, f64, f64)) -> Point<T>
Sets the color of the point.
Returns the point itself to allow chaining.
Sourcepub fn with_label(self, label: String) -> Point<T>
pub fn with_label(self, label: String) -> Point<T>
Sets the label of the point.
Returns the point itself to allow chaining.